@@ -8,12 +8,15 @@ from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
 
-import sys
 import os
 import fnmatch
 
+from future.utils import raise_from
+
 from nose.importer import Importer
 
+from aloe.exceptions import StepDiscoveryError
+
 
 def path_to_module_name(filename):
     """Convert a path to a file to a Python module name."""
@@ -52,14 +55,15 @@ class FeatureLoader(object):
                 filename = os.path.relpath(os.path.join(path, filename))
                 module_name = path_to_module_name(filename)
 
-                # Ensure the module is loaded anew, so that its steps and hooks
-                # are registered again
                 try:
-                    del sys.modules[module_name]
-                except KeyError:
-                    pass
-
-                cls.importer.importFromPath(filename, module_name)
+                    cls.importer.importFromPath(filename, module_name)
+                except ImportError as exc:
+                    raise_from(
+                        StepDiscoveryError(
+                            "Cannot load step definition file: '%s'" % filename
+                        ),
+                        exc
+                    )
 
     @classmethod
     def find_feature_directories(cls, dir_):
@@ -74,7 +78,7 @@ class FeatureLoader(object):
         # A set of package directories discovered
         packages = set()
 
-        for path, dirs, files in os.walk(dir_):
+        for path, dirs, files in os.walk(dir_, followlinks=True):
             # Is this a package?
             if '__init__.py' in files:
                 packages.add(path)
