@@ -1,20 +1,4 @@
 # -*- coding: utf-8 -*-
-# Aloe - Cucumber runner for Python based on Lettuce and Nose
-# Copyright (C) <2010-2012>  Gabriel Falcão <gabriel@nacaolivre.org>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Utilities for working with strings.
 """
@@ -27,13 +11,11 @@ from __future__ import absolute_import
 from builtins import str
 from builtins import zip
 # pylint:enable=redefined-builtin
-from future import standard_library
-standard_library.install_aliases()
 
 import unicodedata
 
 
-def represent_table(table, indent=0, cell_wrap=lambda s: s):
+def represent_table(table, indent=0, cell_wrap=str):
     """
     Render a table
 
