@@ -1,19 +1,3 @@
-# Aloe - Cucumber runner for Python based on Lettuce and Nose
-# Copyright (C) <2015> Alexey Kotlyarov <a@koterpillar.com>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Test step loading.
 """
@@ -22,8 +6,6 @@ from __future__ import unicode_literals
 from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 
 import os
 
@@ -58,8 +40,9 @@ class StepLoadingTest(FeatureTest):
         """
         Test running all the features without explicitly specifying them.
 
-        Features not in packages (not_a_submodule, python_inside/package)
-        should not be run.
+        Neither features not in packages
+        (not_a_submodule, python_inside/package)
+        nor features not in directories named "features" should be run.
         """
 
         result = self.assert_feature_success()
