@@ -1,19 +1,3 @@
-# Aloe - Cucumber runner for Python based on Lettuce and Nose
-# Copyright (C) <2015> Alexey Kotlyarov <a@koterpillar.com>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Test code generation utilities.
 """
@@ -22,17 +6,13 @@ from __future__ import unicode_literals
 from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 
 import unittest
 from contextlib import contextmanager
 
 from aloe.codegen import (
-    indent,
     make_function,
     multi_manager,
-    remove_indent,
 )
 
 
@@ -66,61 +46,6 @@ class TestCodegen(unittest.TestCase):
         self.assertEqual(adder.__name__, 'adder')
 
 
-class TestIndent(unittest.TestCase):
-    """
-    Test indentation utilities.
-    """
-
-    def test_indent(self):
-        """Test indent()."""
-        original = '\n'.join((
-            'def one():',
-            '    pass',
-            '',
-            'def two():',
-            '    pass',
-            '',
-        ))
-
-        self.assertEqual(indent(original), '\n'.join((
-            '    def one():',
-            '        pass',
-            '',
-            '    def two():',
-            '        pass',
-            '',
-        )))
-
-        self.assertEqual(indent(original, 3), '\n'.join((
-            '            def one():',
-            '                pass',
-            '',
-            '            def two():',
-            '                pass',
-            '',
-        )))
-
-    def test_remove_indent(self):
-        """Test remove_indent()."""
-        original = '\n'.join((
-            '    def one():',
-            '        pass',
-            '',
-            '    def two():',
-            '        pass',
-            '    ',
-        ))
-
-        self.assertEqual(remove_indent(original), '\n'.join((
-            'def one():',
-            '    pass',
-            '',
-            'def two():',
-            '    pass',
-            '',
-        )))
-
-
 class TestMultiManager(unittest.TestCase):
     """
     Test multi_manager.
