@@ -1,20 +1,4 @@
 # -*- coding: utf-8 -*-
-# Aloe - Cucumber runner for Python based on Lettuce and Nose
-# Copyright (C) <2010-2012>  Gabriel Falcão <gabriel@nacaolivre.org>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Test French language parsing.
 """
@@ -23,11 +7,8 @@ from __future__ import unicode_literals
 from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 
 from nose.tools import assert_equal
-from aloe.languages import Language
 from aloe.parser import Feature
 
 SCENARIO = u"""
@@ -39,7 +20,7 @@ Scénario: Ajout de plusieurs cursus dans la base de mon université
     Quand je consolide la base dans 'cursus.txt'
     Alors je vois que la 1er ligne de 'cursus.txt' contient 'Science de l'Informatique:5
     Et je vois que la 2em ligne de 'cursus.txt' contient 'Nutrition:4'
-"""  # noqa
+"""
 
 OUTLINED_SCENARIO = u"""
 Plan du Scénario: Ajouter 2 nombres
@@ -122,38 +103,22 @@ Fonctionnalité: Faire plusieur choses en même temps
 
 def parse_scenario(string, language=None):
     """Parse a scenario, prefixing it with a feature header."""
-    feature = u"""
+    feature_str = u"""
     Fonctionnalité: parse_scenario
     """
 
-    feature += string
-    feature = Feature.from_string(feature, language=language)
+    feature_str += string
+    feature = Feature.from_string(feature_str, language=language)
 
     return feature.scenarios[0]
 
 
-def test_language_french():
-    """
-    Language: FR -> Language class supports french through code "fr"
-    """
-
-    lang = Language('fr')
-
-    assert_equal(lang.code, u'fr')
-    assert_equal(lang.name, u'French')
-    assert_equal(lang.native, u'Français')
-    assert_equal(lang.FEATURE, u'Fonctionnalité')
-    assert_equal(lang.SCENARIO, u'Scénario')
-    assert_equal(lang.EXAMPLES, u'Exemples')
-
-
 def test_scenario_fr_from_string():
     """
     Language: FR -> Scenario.from_string
     """
 
-    lang = Language('fr')
-    scenario = parse_scenario(SCENARIO, language=lang)
+    scenario = parse_scenario(SCENARIO, language='fr')
 
     assert_equal(
         scenario.name,
@@ -161,10 +126,10 @@ def test_scenario_fr_from_string():
     )
     assert_equal(
         scenario.steps[0].hashes,
-        [
+        (
             {'Nom': u"Science de l'Informatique", u'Durée': '5 ans'},
             {'Nom': u'Nutrition', u'Durée': '4 ans'},
-        ]
+        )
     )
 
 
@@ -173,8 +138,7 @@ def test_scenario_outline1_fr_from_string():
     Language: FR -> Scenario.from_string, with scenario outline, first case
     """
 
-    lang = Language('fr')
-    scenario = parse_scenario(OUTLINED_SCENARIO, language=lang)
+    scenario = parse_scenario(OUTLINED_SCENARIO, language='fr')
 
     assert_equal(
         scenario.name,
@@ -182,14 +146,14 @@ def test_scenario_outline1_fr_from_string():
     )
     assert_equal(
         scenario.outlines,
-        [
+        (
             {u'input_1': u'20', u'input_2': u'30',
              u'bouton': u'add', u'output': u'50'},
             {u'input_1': u'2', u'input_2': u'5',
              u'bouton': u'add', u'output': u'7'},
             {u'input_1': u'0', u'input_2': u'40',
              u'bouton': u'add', u'output': u'40'},
-        ]
+        )
     )
 
 
@@ -198,8 +162,7 @@ def test_scenario_outline2_fr_from_string():
     Language: FR -> Scenario.from_string, with scenario outline, second case
     """
 
-    lang = Language('fr')
-    scenario = parse_scenario(OUTLINED_SCENARIO2, language=lang)
+    scenario = parse_scenario(OUTLINED_SCENARIO2, language='fr')
 
     assert_equal(
         scenario.name,
@@ -207,14 +170,14 @@ def test_scenario_outline2_fr_from_string():
     )
     assert_equal(
         scenario.outlines,
-        [
+        (
             {u'input_1': u'20', u'input_2': u'30',
              u'bouton': u'add', u'output': u'50'},
             {u'input_1': u'2', u'input_2': u'5',
              u'bouton': u'add', u'output': u'7'},
             {u'input_1': u'0', u'input_2': u'40',
              u'bouton': u'add', u'output': u'40'},
-        ]
+        )
     )
 
 
@@ -223,8 +186,7 @@ def test_scenario_outline3_fr_from_string():
     Language: FR -> Scenario.from_string, with scenario outline, third case
     """
 
-    lang = Language('fr')
-    scenario = parse_scenario(OUTLINED_SCENARIO2, language=lang)
+    scenario = parse_scenario(OUTLINED_SCENARIO2, language='fr')
 
     assert_equal(
         scenario.name,
@@ -232,14 +194,14 @@ def test_scenario_outline3_fr_from_string():
     )
     assert_equal(
         scenario.outlines,
-        [
+        (
             {u'input_1': u'20', u'input_2': u'30',
              u'bouton': u'add', u'output': u'50'},
             {u'input_1': u'2', u'input_2': u'5',
              u'bouton': u'add', u'output': u'7'},
             {u'input_1': u'0', u'input_2': u'40',
              u'bouton': u'add', u'output': u'40'},
-        ]
+        )
     )
 
 
@@ -248,9 +210,7 @@ def test_feature_fr_from_string():
     Language: FR -> Feature.from_string
     """
 
-    lang = Language('fr')
-
-    feature = Feature.from_string(OUTLINED_FEATURE, language=lang)
+    feature = Feature.from_string(OUTLINED_FEATURE, language='fr')
 
     assert_equal(
         feature.name,
@@ -273,14 +233,14 @@ def test_feature_fr_from_string():
 
     assert_equal(
         scenario.outlines,
-        [
+        (
             {u'input_1': u'20', u'input_2': u'30',
              u'bouton': u'add', u'output': u'50'},
             {u'input_1': u'2', u'input_2': u'5',
              u'bouton': u'add', u'output': u'7'},
             {u'input_1': u'0', u'input_2': u'40',
              u'bouton': u'add', u'output': u'40'},
-        ]
+        )
     )
 
 
@@ -289,9 +249,7 @@ def test_feature_fr_from_string2():
     Language: FR -> Feature.from_string, alternate name
     """
 
-    lang = Language('fr')
-
-    feature = Feature.from_string(OUTLINED_FEATURE2, language=lang)
+    feature = Feature.from_string(OUTLINED_FEATURE2, language='fr')
 
     assert_equal(
         feature.name,
@@ -314,12 +272,12 @@ def test_feature_fr_from_string2():
 
     assert_equal(
         scenario.outlines,
-        [
+        (
             {u'input_1': u'20', u'input_2': u'30',
              u'bouton': u'add', u'output': u'50'},
             {u'input_1': u'2', u'input_2': u'5',
              u'bouton': u'add', u'output': u'7'},
             {u'input_1': u'0', u'input_2': u'40',
              u'bouton': u'add', u'output': u'40'},
-        ]
+        )
     )
